# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: automatonOutput.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='automatonOutput.proto',
  package='colav',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x15\x61utomatonOutput.proto\x12\x05\x63olav\"\xe6\x04\n\x0f\x41utomatonOutput\x12\x16\n\x0e\x61utomaton_uuid\x18\x01 \x01(\t\x12\x0c\n\x04mode\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\x31\n\x08\x64ynamics\x18\x04 \x01(\x0b\x32\x1f.colav.AutomatonOutput.Dynamics\x12\x32\n\twaypoints\x18\x05 \x03(\x0b\x32\x1f.colav.AutomatonOutput.Waypoint\x12+\n\x05stamp\x18\x06 \x01(\x0b\x32\x1c.colav.AutomatonOutput.Stamp\x12\x32\n\x0c\x65lapsed_time\x18\x07 \x01(\x0b\x32\x1c.colav.AutomatonOutput.Stamp\x12\r\n\x05\x65rror\x18\x08 \x01(\x08\x12\x0f\n\x07message\x18\t \x01(\t\x1a(\n\x05Point\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\x12\t\n\x01z\x18\x03 \x01(\x02\x1aU\n\x08Waypoint\x12.\n\x08position\x18\x01 \x01(\x0b\x32\x1c.colav.AutomatonOutput.Point\x12\x19\n\x11\x61\x63\x63\x65ptance_radius\x18\x02 \x01(\x02\x1a\x8c\x01\n\x08\x44ynamics\x12\x17\n\x0f\x63ontroller_name\x18\x01 \x01(\t\x12\x36\n\x03\x63md\x18\x02 \x01(\x0b\x32).colav.AutomatonOutput.Dynamics.CmdVelYaw\x1a/\n\tCmdVelYaw\x12\x10\n\x08velocity\x18\x01 \x01(\x02\x12\x10\n\x08yaw_rate\x18\x02 \x01(\x02\x1a%\n\x05Stamp\x12\x0b\n\x03sec\x18\x01 \x01(\r\x12\x0f\n\x07nanosec\x18\x02 \x01(\rb\x06proto3'
)




_AUTOMATONOUTPUT_POINT = _descriptor.Descriptor(
  name='Point',
  full_name='colav.AutomatonOutput.Point',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='colav.AutomatonOutput.Point.x', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='colav.AutomatonOutput.Point.y', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='z', full_name='colav.AutomatonOutput.Point.z', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=338,
  serialized_end=378,
)

_AUTOMATONOUTPUT_WAYPOINT = _descriptor.Descriptor(
  name='Waypoint',
  full_name='colav.AutomatonOutput.Waypoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='position', full_name='colav.AutomatonOutput.Waypoint.position', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acceptance_radius', full_name='colav.AutomatonOutput.Waypoint.acceptance_radius', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=380,
  serialized_end=465,
)

_AUTOMATONOUTPUT_DYNAMICS_CMDVELYAW = _descriptor.Descriptor(
  name='CmdVelYaw',
  full_name='colav.AutomatonOutput.Dynamics.CmdVelYaw',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='velocity', full_name='colav.AutomatonOutput.Dynamics.CmdVelYaw.velocity', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaw_rate', full_name='colav.AutomatonOutput.Dynamics.CmdVelYaw.yaw_rate', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=561,
  serialized_end=608,
)

_AUTOMATONOUTPUT_DYNAMICS = _descriptor.Descriptor(
  name='Dynamics',
  full_name='colav.AutomatonOutput.Dynamics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='controller_name', full_name='colav.AutomatonOutput.Dynamics.controller_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cmd', full_name='colav.AutomatonOutput.Dynamics.cmd', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_AUTOMATONOUTPUT_DYNAMICS_CMDVELYAW, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=468,
  serialized_end=608,
)

_AUTOMATONOUTPUT_STAMP = _descriptor.Descriptor(
  name='Stamp',
  full_name='colav.AutomatonOutput.Stamp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sec', full_name='colav.AutomatonOutput.Stamp.sec', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nanosec', full_name='colav.AutomatonOutput.Stamp.nanosec', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=610,
  serialized_end=647,
)

_AUTOMATONOUTPUT = _descriptor.Descriptor(
  name='AutomatonOutput',
  full_name='colav.AutomatonOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='automaton_uuid', full_name='colav.AutomatonOutput.automaton_uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mode', full_name='colav.AutomatonOutput.mode', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='colav.AutomatonOutput.status', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dynamics', full_name='colav.AutomatonOutput.dynamics', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='waypoints', full_name='colav.AutomatonOutput.waypoints', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stamp', full_name='colav.AutomatonOutput.stamp', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='elapsed_time', full_name='colav.AutomatonOutput.elapsed_time', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error', full_name='colav.AutomatonOutput.error', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='colav.AutomatonOutput.message', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_AUTOMATONOUTPUT_POINT, _AUTOMATONOUTPUT_WAYPOINT, _AUTOMATONOUTPUT_DYNAMICS, _AUTOMATONOUTPUT_STAMP, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=33,
  serialized_end=647,
)

_AUTOMATONOUTPUT_POINT.containing_type = _AUTOMATONOUTPUT
_AUTOMATONOUTPUT_WAYPOINT.fields_by_name['position'].message_type = _AUTOMATONOUTPUT_POINT
_AUTOMATONOUTPUT_WAYPOINT.containing_type = _AUTOMATONOUTPUT
_AUTOMATONOUTPUT_DYNAMICS_CMDVELYAW.containing_type = _AUTOMATONOUTPUT_DYNAMICS
_AUTOMATONOUTPUT_DYNAMICS.fields_by_name['cmd'].message_type = _AUTOMATONOUTPUT_DYNAMICS_CMDVELYAW
_AUTOMATONOUTPUT_DYNAMICS.containing_type = _AUTOMATONOUTPUT
_AUTOMATONOUTPUT_STAMP.containing_type = _AUTOMATONOUTPUT
_AUTOMATONOUTPUT.fields_by_name['dynamics'].message_type = _AUTOMATONOUTPUT_DYNAMICS
_AUTOMATONOUTPUT.fields_by_name['waypoints'].message_type = _AUTOMATONOUTPUT_WAYPOINT
_AUTOMATONOUTPUT.fields_by_name['stamp'].message_type = _AUTOMATONOUTPUT_STAMP
_AUTOMATONOUTPUT.fields_by_name['elapsed_time'].message_type = _AUTOMATONOUTPUT_STAMP
DESCRIPTOR.message_types_by_name['AutomatonOutput'] = _AUTOMATONOUTPUT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AutomatonOutput = _reflection.GeneratedProtocolMessageType('AutomatonOutput', (_message.Message,), {

  'Point' : _reflection.GeneratedProtocolMessageType('Point', (_message.Message,), {
    'DESCRIPTOR' : _AUTOMATONOUTPUT_POINT,
    '__module__' : 'automatonOutput_pb2'
    # @@protoc_insertion_point(class_scope:colav.AutomatonOutput.Point)
    })
  ,

  'Waypoint' : _reflection.GeneratedProtocolMessageType('Waypoint', (_message.Message,), {
    'DESCRIPTOR' : _AUTOMATONOUTPUT_WAYPOINT,
    '__module__' : 'automatonOutput_pb2'
    # @@protoc_insertion_point(class_scope:colav.AutomatonOutput.Waypoint)
    })
  ,

  'Dynamics' : _reflection.GeneratedProtocolMessageType('Dynamics', (_message.Message,), {

    'CmdVelYaw' : _reflection.GeneratedProtocolMessageType('CmdVelYaw', (_message.Message,), {
      'DESCRIPTOR' : _AUTOMATONOUTPUT_DYNAMICS_CMDVELYAW,
      '__module__' : 'automatonOutput_pb2'
      # @@protoc_insertion_point(class_scope:colav.AutomatonOutput.Dynamics.CmdVelYaw)
      })
    ,
    'DESCRIPTOR' : _AUTOMATONOUTPUT_DYNAMICS,
    '__module__' : 'automatonOutput_pb2'
    # @@protoc_insertion_point(class_scope:colav.AutomatonOutput.Dynamics)
    })
  ,

  'Stamp' : _reflection.GeneratedProtocolMessageType('Stamp', (_message.Message,), {
    'DESCRIPTOR' : _AUTOMATONOUTPUT_STAMP,
    '__module__' : 'automatonOutput_pb2'
    # @@protoc_insertion_point(class_scope:colav.AutomatonOutput.Stamp)
    })
  ,
  'DESCRIPTOR' : _AUTOMATONOUTPUT,
  '__module__' : 'automatonOutput_pb2'
  # @@protoc_insertion_point(class_scope:colav.AutomatonOutput)
  })
_sym_db.RegisterMessage(AutomatonOutput)
_sym_db.RegisterMessage(AutomatonOutput.Point)
_sym_db.RegisterMessage(AutomatonOutput.Waypoint)
_sym_db.RegisterMessage(AutomatonOutput.Dynamics)
_sym_db.RegisterMessage(AutomatonOutput.Dynamics.CmdVelYaw)
_sym_db.RegisterMessage(AutomatonOutput.Stamp)


# @@protoc_insertion_point(module_scope)
